﻿using System.Drawing;
using System.Windows.Forms;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 좌상단 사각형
        /// </summary>
        private Rectangle leftTopRectangle = new Rectangle(200, 100, 200, 200);

        /// <summary>
        /// 우상단 사각형
        /// </summary>
        private Rectangle rightTopRectangle = new Rectangle(400, 100, 200, 200);

        /// <summary>
        /// 좌하단 사각형
        /// </summary>
        private Rectangle leftBottomRectangle = new Rectangle(200, 300, 200, 200);

        /// <summary>
        /// 우하단 사각형
        /// </summary>
        private Rectangle rightBottomRectangle = new Rectangle(400, 300, 200, 200);

        /// <summary>
        /// 커스텀 커서
        /// </summary>
        private Cursor customCursor = new Cursor("CURSOR\\custom.cur");

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            MouseMove += Form_MouseMove;
            Paint     += Form_Paint;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 마우스 이동시 처리하기 - Form_MouseMove(sender, e)

        /// <summary>
        /// 폼 마우스 이동시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_MouseMove(object sender, MouseEventArgs e)
        {
            Point mousePoint = e.Location;

            if(this.leftTopRectangle.Contains(mousePoint))
            {
                Cursor = this.customCursor;
            }
            else if(this.rightTopRectangle.Contains(mousePoint))
            {
                Cursor = Cursors.Hand;
            }
            else if(this.leftBottomRectangle.Contains(mousePoint))
            {
                Cursor = Cursors.VSplit;
            }
            else if(this.rightBottomRectangle.Contains(mousePoint))
            {
                Cursor = Cursors.UpArrow;
            }
            else
            {
                Cursor = Cursors.Default;
            }
        }

        #endregion
        #region 폼 페인트시 처리하기 - Form_Paint(sender, e)

        /// <summary>
        /// 폼 페인트시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Paint(object sender, PaintEventArgs e)
        {
            Graphics graphics = e.Graphics;

            graphics.FillRectangle(Brushes.Blue  , this.leftTopRectangle    );
            graphics.FillRectangle(Brushes.Red   , this.rightTopRectangle   );
            graphics.FillRectangle(Brushes.Yellow, this.leftBottomRectangle );
            graphics.FillRectangle(Brushes.Green , this.rightBottomRectangle);
        }

        #endregion
    }
}